@@ -1,14 +1,14 @@
-# Copyrights 2008-2014 by [Mark Overmeer].
+# Copyrights 2008-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 # extends the implementation of Geo::GML, autoloaded
 package Geo::GML;
 use vars '$VERSION';
-$VERSION = '0.16';
+$VERSION = '0.17';
 
 
 use Log::Report 'geo-gml', syntax => 'SHORT';
@@ -66,16 +66,13 @@ sub _gml2_space($$)
     # wrong: Space can contain other objects as well.
     my @members;
     foreach my $c ($space->components)
-    {   my $outer = $self->_gml2_line($c->geoOuter, $args);
-        my @inner = map { $self->_gml2_line($_, $args) } $c->geoInner;
-        my %poly  = ( gml_outerBoundaryIs => $outer
-                    , gml_innerBoundaryIs => \@inner);
-        push @members, +{ gml_polygonMember => {gml_Polygon => \%poly} };
+    {   $c = Geo::Surface->new($c) if $c->isa('Geo::Line');
+        push @members, { gml_polygonMember => $self->_gml2_surface($c, $args) };
     }
 
    +{ gml_MultiPolygon =>
       { seq_gml_polygonMember => \@members
-      , srsName => $args->{_srsName}
+       , srsName => $args->{_srsName}
       }
     };
 }
@@ -84,7 +81,8 @@ sub _gml2_surface($$)
 {   my ($self, $surface, $args) = @_;
 
     my $outer = $self->_gml2_line($surface->geoOuter, $args);
-    my @inner = map { $self->_gml2_line($_, $args) } $surface->geoInner;
+    my @inner = map $self->_gml2_line($_, $args), $surface->geoInner;
+
     my %poly  = ( gml_outerBoundaryIs => $outer
                 , gml_innerBoundaryIs => \@inner);
    +{ gml_Polygon => \%poly
@@ -97,7 +95,7 @@ sub _gml2_line($$)
     defined $line or return;
 
     my ($cs, $ts) = (',', ' ');
-    my $coords = join $ts, map {$_->[0].$cs.$_->[1] } $line->points;
+    my $coords = join $ts, map $_->[0].$cs.$_->[1], $line->points;
 
    +{ gml_LinearRing =>
       { gml_coordinates =>
@@ -122,7 +120,7 @@ sub _gml2_point($$)
 
 sub _gml2_shape($$)
 {   my ($self, $shape, $args) = @_;
-    panic "GML2 shape not implemented yet";
+    panic "object type ".(ref $shape). "not implemented yet";
 }
 
 #
@@ -134,10 +132,11 @@ sub _gml3_space($$)
     my @members;
 
     foreach my $c ($space->components)
-    {   my $outer = $self->_gml3_line($c->geoOuter, $args);
-        my @inner = map { $self->_gml3_line($_, $args) } $c->geoInner;
-        my %poly  = (gml_exterior => $outer, gml_interior => \@inner);
-        push @members, +{ gml_Polygon => \%poly };
+    {  $c = Geo::Surface->new($c) if $c->isa('Geo::Line');
+       push @members, $self->_gml3_surface($c, $args);
+#         , $c->isa('Geo::Line')
+#         ? $self->_gml3_line($c, $args)
+#         : $self->_gml3_surface($c, $args);
     }
 
     my $surftype =
@@ -155,7 +154,7 @@ sub _gml3_surface($$)
     my @members;
 
     my $outer = $self->_gml3_line($surface->geoOuter, $args);
-    my @inner = map { $self->_gml3_line($_, $args) } $surface->geoInner;
+    my @inner = map $self->_gml3_line($_, $args), $surface->geoInner;
     my %poly  = (gml_exterior => $outer, gml_interior => \@inner);
     +{ gml_Polygon => \%poly };
 }
@@ -166,8 +165,8 @@ sub _gml3_line($$)
 
     my @points = $line->points;
     my @coords = $line->proj4->isLatlong
-       ? (map { ($_->[1], $_->[0]) } @points)
-       : (map { ($_->[0], $_->[1]) } @points);
+       ? (map +($_->[1], $_->[0]), @points)
+       : (map +($_->[0], $_->[1]), @points);
 
    +{ gml_LinearRing =>
       { gml_posList => { _ => \@coords, count => scalar(@points) } }
@@ -186,7 +185,7 @@ sub _gml3_point($$)
 
 sub _gml3_shape($$)
 {   my ($self, $shape, $args) = @_;
-    panic "Not implemented yet";
+    panic "object type ".(ref $shape). "not implemented yet";
 }
 
 1;
